==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
var DataGridSummaryResultDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataGridSummaryResultDescriptionMetadata, _super);
    function DataGridSummaryResultDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataGridSummaryResultDescriptionMetadata.b = function (a) {
        if (DataGridSummaryResultDescriptionMetadata.a == null) {
            DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
        }
        if (a.j(DataGridSummaryResultDescriptionMetadata.a)) {
            return;
        }
        a.y(DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.c = function (a) {
        a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
        a.item("Value", "Unknown");
        a.item("SummaryIndex", "Number:int");
    };
    DataGridSummaryResultDescriptionMetadata.d = function (a) {
        DataGridSummaryResultDescriptionMetadata.b(a);
        a.aa("DataGridSummaryResult", function () { return new DataGridSummaryResultDescription(); });
        a.z("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.$t = markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
}(Base));
export { DataGridSummaryResultDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
var DataGridSummaryResultDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataGridSummaryResultDescriptionMetadata, _super);
    function DataGridSummaryResultDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataGridSummaryResultDescriptionMetadata.b = function (a) {
        if (DataGridSummaryResultDescriptionMetadata.a == null) {
            DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
        }
        if (a.k(DataGridSummaryResultDescriptionMetadata.a)) {
            return;
        }
        a.aa(DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.c = function (a) {
        a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
        a.item("Value", "Unknown");
        a.item("SummaryIndex", "Number:int");
    };
    DataGridSummaryResultDescriptionMetadata.d = function (a) {
        DataGridSummaryResultDescriptionMetadata.b(a);
        a.ac("DataGridSummaryResult", function () { return new DataGridSummaryResultDescription(); });
        a.ab("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.$t = markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
}(Base));
export { DataGridSummaryResultDescriptionMetadata };
